@@ -1,4 +1,4 @@
-UniGASFor <- function(uGASFit, H, Roll = FALSE, out = NULL, B = 10000, Bands = c(0.1, 0.15, 0.85, 0.9), ReturnDraws = FALSE) {
+UniGASFor <- function(uGASFit, H = NULL, Roll = FALSE, out = NULL, B = 10000, Bands = c(0.1, 0.15, 0.85, 0.9), ReturnDraws = FALSE) {
 
     vOut = out
     if (Roll) {
@@ -13,7 +13,7 @@ UniGASFor <- function(uGASFit, H, Roll = FALSE, out = NULL, B = 10000, Bands = c
 
     iK = uGASFit@ModelInfo$iK
     ScalingType = getScalingType(uGASFit)
-    lParList = coef(uGASFit)$lCoef
+    lParList = coef(uGASFit, do.list = TRUE)$lCoef
     Dist = getDist(uGASFit)
     GASPar = getGASPar(uGASFit)
     vY = getObs(uGASFit)
@@ -81,21 +81,36 @@ UniGASFor <- function(uGASFit, H, Roll = FALSE, out = NULL, B = 10000, Bands = c
       }
     }
 
-    Out <- new("uGASFor", Forecast = list(PointForecast = PointForecast, Moments = mMoments, vU = vU,
-        vLS = vLS), Bands = cBands, Draws = mY, Info = list(iH = iH, Roll = Roll, iB = iB, vBands = vBands,
-        bReturnDraws = bReturnDraws, GASPar = GASPar, Dist = Dist, ScalingType = ScalingType, iK = iK),
-        Data = list(vY = vY, FilteredParameters = FilteredParameters, vOut = vOut))
+    Out <- new("uGASFor",
+               Forecast = list(PointForecast = PointForecast,
+                               Moments = mMoments,
+                               vU = vU,
+                               vLS = vLS),
+               Bands = cBands,
+               Draws = mY,
+               Info = list(iH = iH,
+                           Roll = Roll,
+                           iB = iB,
+                           vBands = vBands,
+                           bReturnDraws = bReturnDraws,
+                           GASPar = GASPar,
+                           Dist = Dist,
+                           ScalingType = ScalingType,
+                           iK = iK),
+               Data = list(vY = vY,
+                           FilteredParameters = FilteredParameters,
+                           vOut = vOut))
 
     return(Out)
 
 }
 
-MultiGASFor <- function(mGASFit, H, Roll = FALSE, out = NULL, B = 10000, Bands = c(0.1, 0.15, 0.85, 0.9),
+MultiGASFor <- function(mGASFit, H = NULL, Roll = FALSE, out = NULL, B = 10000, Bands = c(0.1, 0.15, 0.85, 0.9),
     ReturnDraws = FALSE) {
 
     if (Roll) {
 
-      if(is.null(out)) stop("When Roll = TRUE, 'out' must be submitted")
+      if (is.null(out)) stop("When Roll = TRUE, 'out' must be submitted")
 
       mOut = t(out)
       H = ncol(mOut)
@@ -120,7 +135,7 @@ MultiGASFor <- function(mGASFit, H, Roll = FALSE, out = NULL, B = 10000, Bands =
     iK = mGASFit@ModelInfo$iK
     iN = mGASFit@ModelInfo$iN
     ScalingType = getScalingType(mGASFit)
-    lParList = coef(mGASFit)$lCoef
+    lParList = coef(mGASFit, do.list = TRUE)$lCoef
     Dist = getDist(mGASFit)
     GASPar = getGASPar(mGASFit)
     mY = getObs(mGASFit)
@@ -176,21 +191,38 @@ MultiGASFor <- function(mGASFit, H, Roll = FALSE, out = NULL, B = 10000, Bands =
     colnames(PointForecast) = FullNamesMulti(iN, Dist)
     rownames(PointForecast) = vOutDate
 
-    if( any(class(out)[1] == c("xts", "ts", "zoo"))) PointForecast = xts(PointForecast, order.by = index(out))
+    if (any(class(out)[1] == c("xts", "ts", "zoo"))) {
+      PointForecast = xts(PointForecast, order.by = index(out))
+    }
 
     lMoments = EvalMoments_multi(t(PointForecast), Dist, iN)
 
-    Out <- new("mGASFor", Forecast = list(PointForecast = PointForecast, Moments = lMoments, vLS = vLS),
-        Bands = cBands, Draws = cY, Info = list(iH = iH, iN = iN, Roll = Roll, iB = iB, vBands = vBands,
-            bReturnDraws = bReturnDraws, GASPar = GASPar, Dist = Dist, ScalingType = ScalingType, iK = iK),
-        Data = list(mY = mY, FilteredParameters = FilteredParameters, mOut = mOut))
+    Out <- new("mGASFor",
+               Forecast = list(PointForecast = PointForecast,
+                               Moments = lMoments,
+                               vLS = vLS),
+               Bands = cBands,
+               Draws = cY,
+               Info = list(iH = iH,
+                           iN = iN,
+                           Roll = Roll,
+                           iB = iB,
+                           vBands = vBands,
+                           bReturnDraws = bReturnDraws,
+                           GASPar = GASPar,
+                           Dist = Dist,
+                           ScalingType = ScalingType,
+                           iK = iK),
+               Data = list(mY = mY,
+                           FilteredParameters = FilteredParameters,
+                           mOut = mOut))
 
     return(Out)
 
 }
 
 UniGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, RefitEvery = 23, RefitWindow = c("moving",
-    "recursive"), cluster = NULL) {
+    "recursive"), cluster = NULL, ...) {
 
     StartTime = Sys.time()
 
@@ -199,14 +231,13 @@ UniGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Refit
     iT = length(vY)
 
     Dist = getDist(GASSpec)
-    ScalingType = getScalingType(GASSpec)
-    GASPar = getGASPar(GASSpec)
     iK = NumberParameters(Dist)
 
-    if (!is.null(cluster))
+    if (!is.null(cluster)) {
         clusterEvalQ(cluster, {
             library(GAS)
         })
+    }
     if (!is.null(Nstart)) {
         iStart = Nstart
     } else {
@@ -214,8 +245,9 @@ UniGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Refit
     }
 
     FitIndex = seq(iStart, iT, RefitEvery)
-    if (tail(FitIndex, 1) == iT)
+    if (tail(FitIndex, 1) == iT) {
         FitIndex = FitIndex[-length(FitIndex)]
+    }
 
     lFits = list()
     lForecasts = list()
@@ -233,10 +265,12 @@ UniGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Refit
         }
     }
     # fits
-    if (is.null(cluster))
-        lFits = lapply(lData, UniGASFit, GASSpec = GASSpec)
-    if (!is.null(cluster))
-        lFits = parLapply(cluster, lData, UniGASFit, GASSpec = GASSpec)
+    if (is.null(cluster)) {
+        lFits = lapply(lData, UniGASFit, GASSpec = GASSpec, ... = ...)
+    }
+    if (!is.null(cluster)) {
+        lFits = parLapply(cluster, lData, UniGASFit, GASSpec = GASSpec, ... = ...)
+    }
 
     # coef
     lCoef = lapply(lFits, coef)
@@ -247,6 +281,7 @@ UniGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Refit
         vU = EvaluatePit_Univ(t(mForc), tail(vY, ForecastLength), Dist, ForecastLength)
         vLS = EvaluateLogScore_Univ(t(mForc), tail(vY, ForecastLength), Dist, ForecastLength)
         Moments = EvalMoments_univ(t(mForc), Dist)
+
     } else {
 
         for (i in 1:length(FitIndex)) {
@@ -259,7 +294,7 @@ UniGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Refit
 
         lForecasts = lapply(1:length(lOut), function(i, lFits, lOut) {
 
-            UniGASFor(uGASFit = lFits[[i]], out = lOut[[i]], Roll = T)
+            UniGASFor(uGASFit = lFits[[i]], out = lOut[[i]], Roll = TRUE)
 
         }, lFits = lFits, lOut = lOut)
 
@@ -269,20 +304,32 @@ UniGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Refit
         Moments = do.call(rbind, lapply(lForecasts, getMoments))
     }
 
-    PitTest = PIT_test(vU, G = 20, alpha = 0.05, plot = F)
+    PitTest = PIT_test(vU, G = 20, alpha = 0.05, plot = FALSE)
 
     elapsedTime = Sys.time() - StartTime
 
-    Out <- new("uGASRoll", Forecast = list(PointForecast = mForc, vU = vU, vLS = vLS, Moments = Moments,
-        Coef = lCoef), Info = list(GASSpec = GASSpec, ForecastLength = ForecastLength, RefitEvery = RefitEvery,
-        RefitWindow = RefitWindow[1], iT = iT, iK = iK, elapsedTime = elapsedTime), Testing = list(PitTest = PitTest),
-        Data = list(vY = vY))
+    Out <- new("uGASRoll",
+               Forecast = list(PointForecast = mForc,
+                               vU = vU,
+                               vLS = vLS,
+                               Moments = Moments,
+                               Coef = lCoef),
+               Info = list(GASSpec = GASSpec,
+                           ForecastLength = ForecastLength,
+                           RefitEvery = RefitEvery,
+                           RefitWindow = RefitWindow[1],
+                           iT = iT,
+                           iK = iK,
+                           elapsedTime = elapsedTime),
+               Testing = list(PitTest = PitTest),
+               Data = list(vY = vY))
+
     return(Out)
 
 }
 
 MultiGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, RefitEvery = 23, RefitWindow = c("moving",
-    "recursive"), cluster = NULL) {
+    "recursive"), cluster = NULL, ...) {
 
     StartTime = Sys.time()
 
@@ -292,8 +339,6 @@ MultiGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Ref
     iN = nrow(mY)
 
     Dist = getDist(GASSpec)
-    ScalingType = getScalingType(GASSpec)
-    GASPar = getGASPar(GASSpec)
     iK = NumberParameters(Dist, iN)
 
     if (!is.null(cluster))
@@ -326,10 +371,12 @@ MultiGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Ref
         }
     }
     # fits
-    if (is.null(cluster))
-        lFits = lapply(lData, MultiGASFit, GASSpec = GASSpec)
-    if (!is.null(cluster))
-        lFits = parLapply(cluster, lData, MultiGASFit, GASSpec = GASSpec)
+    if (is.null(cluster)) {
+      lFits = lapply(lData, MultiGASFit, GASSpec = GASSpec, ... = ...)
+    }
+    if (!is.null(cluster)) {
+        lFits = parLapply(cluster, lData, MultiGASFit, GASSpec = GASSpec, ... = ...)
+    }
 
     # coef
     lCoef = lapply(lFits, coef)
@@ -353,7 +400,7 @@ MultiGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Ref
 
         lForecasts = lapply(1:length(lOut), function(i, lFits, lOut) {
 
-            MultiGASFor(mGASFit = lFits[[i]], out = lOut[[i]], Roll = T)
+            MultiGASFor(mGASFit = lFits[[i]], out = lOut[[i]], Roll = TRUE)
 
         }, lFits = lFits, lOut = lOut)
 
@@ -365,10 +412,22 @@ MultiGASRoll <- function(data, GASSpec, ForecastLength = 500, Nstart = NULL, Ref
 
     elapsedTime = Sys.time() - StartTime
 
-    Out <- new("mGASRoll", Forecast = list(PointForecast = mForc, vU = vU, vLS = vLS, Moments = Moments,
-        Coef = lCoef), Info = list(GASSpec = GASSpec, ForecastLength = ForecastLength, RefitEvery = RefitEvery,
-        RefitWindow = RefitWindow[1], iT = iT, iK = iK, iN = iN, elapsedTime = elapsedTime), Data = list(mY = mY))
-    return(Out)
+    Out <- new("mGASRoll",
+               Forecast = list(PointForecast = mForc,
+                               vU = vU,
+                               vLS = vLS,
+                               Moments = Moments,
+                               Coef = lCoef),
+               Info = list(GASSpec = GASSpec,
+                           ForecastLength = ForecastLength,
+                           RefitEvery = RefitEvery,
+                           RefitWindow = RefitWindow[1],
+                           iT = iT,
+                           iK = iK,
+                           iN = iN,
+                           elapsedTime = elapsedTime),
+               Data = list(mY = mY))
 
+    return(Out)
 }
 
